diff artifacts/src/main/java/org/dive4elements/river/artifacts/states/DGMSelect.java @ 5867:59ff03ff48f1

River artifacts: Renamed FLYSArtifact(Collection) to D4EArtifact(Collection).
author Sascha L. Teichmann <teichmann@intevation.de>
date Sun, 28 Apr 2013 15:23:01 +0200
parents 73da40528cf2
children af13ceeba52a
line wrap: on
line diff
--- a/artifacts/src/main/java/org/dive4elements/river/artifacts/states/DGMSelect.java	Sun Apr 28 15:14:30 2013 +0200
+++ b/artifacts/src/main/java/org/dive4elements/river/artifacts/states/DGMSelect.java	Sun Apr 28 15:23:01 2013 +0200
@@ -22,7 +22,7 @@
 import org.dive4elements.river.model.DGM;
 import org.dive4elements.river.model.River;
 
-import org.dive4elements.river.artifacts.FLYSArtifact;
+import org.dive4elements.river.artifacts.D4EArtifact;
 import org.dive4elements.river.utils.RiverUtils;
 
 
@@ -47,7 +47,7 @@
 
     @Override
     protected Element createStaticData(
-        FLYSArtifact   flys,
+        D4EArtifact   flys,
         ElementCreator creator,
         CallContext    cc,
         String         name,
@@ -89,7 +89,7 @@
     public boolean validate(Artifact artifact)
     throws IllegalArgumentException
     {
-        FLYSArtifact flys = (FLYSArtifact) artifact;
+        D4EArtifact flys = (D4EArtifact) artifact;
 
         DGM dgm = getDGM(flys);
 
@@ -120,14 +120,14 @@
     /**
      * Returns the DGM specified in the parameters of <i>flys</i>.
      *
      * @param flys The FLYSArtifact that knows the ID of a DGM.
      *
      * @throws IllegalArgumentException If the FLYSArtifact doesn't know the ID
      * of a DGM.
      *
      * @return the DGM specified by FLYSArtifact's parameters.
      */
-    public static DGM getDGM(FLYSArtifact flys)
+    public static DGM getDGM(D4EArtifact flys)
     throws IllegalArgumentException
     {
         try {
@@ -120,14 +120,14 @@
      * Returns the DGM specified in the parameters of <i>flys</i>.
      *
-     * @param flys The FLYSArtifact that knows the ID of a DGM.
+     * @param flys The D4EArtifact that knows the ID of a DGM.
      *
@@ -120,14 +120,14 @@
      *
-     * @throws IllegalArgumentException If the FLYSArtifact doesn't know the ID
+     * @throws IllegalArgumentException If the D4EArtifact doesn't know the ID
      * of a DGM.
      *
@@ -120,14 +120,14 @@
      * of a DGM.
      *
-     * @return the DGM specified by FLYSArtifact's parameters.
+     * @return the DGM specified by D4EArtifact's parameters.
      */

http://dive4elements.wald.intevation.org